@@ -7,6 +7,16 @@ def setup_environment(code_bucket):
     import inspect
     from pathlib import Path
 
+    from rich.console import Console
+    from rich.logging import RichHandler
+
+    logging.basicConfig(
+        level=logging.INFO, format="%(message)s", datefmt="[%X]",
+        handlers=[RichHandler(console=Console(stderr=True))]
+    )
+    log = logging.getLogger("rich")
+    log.setLevel(logging.INFO)
+
     current_directory = os.path.dirname(
         os.path.abspath(inspect.getfile(inspect.currentframe())))
 
