@@ -175,7 +175,7 @@ def push_json_to_s3(s3, json_obj, member_id, annotation_bucket, annotation_path,
 
 
 def process_sample(annotation_bucket, annotation_filename, annotation_path,
-                   samples_bucket, samples_path, member_id):
+                   samples_bucket, samples_path, member_id, code_bucket):
     """
     Process a single member sample
     :param annotation_bucket: the annotation bucket
@@ -184,6 +184,7 @@ def process_sample(annotation_bucket, annotation_filename, annotation_path,
     :param samples_bucket: the samples bucket
     :param samples_path: the samples path
     :param member_id: the member id
+    :param code_bucket: the code bucket where settings are located
     :return:
     """
     import logging
@@ -194,6 +195,9 @@ def process_sample(annotation_bucket, annotation_filename, annotation_path,
     session = boto3.Session()
     s3 = session.resource("s3")
 
+    import environment
+    environment.setup_environment(code_bucket)
+
     logging.info(f'Processing member {member_id}')
 
     samples = get_samples(s3client, member_id, samples_bucket=samples_bucket,
